SaveFirebase class

Constructors

SaveFirebase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createFirebasePaymentID() → String
createProcessingTransaction({required num amount, required String rzpKey, required String appName, String? itemName, required RzpUserProfile userProfile, required String transaction, required String orderId}) → Future<void>
updateFailureTransaction({required String transaction}) → Future<void>
updateSuccessTransaction({required String transaction}) → Future<void>